/* this function formats the NRCVAX space group string into a 
 * neatly formatted string.
 * Written by:
 *	Paul D. Boyle
 *	Department of Chemistry
 *	Box 8204
 *	North Carolina State University
 *	Raleigh, NC 27695-8204
 *
 *	March 1999
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version
 * 2 of the License, or (at your option) any later version.
 */
#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include "sirinp.h"

char *ExtractSpaceGroupSymbol( const Record_2 *r2 )
{
    char tmp_str[40];
    const char *inp_ptr;
    char *out_ptr,
         *ret_val;
    int n_blanks = 0;
    size_t len;

    inp_ptr = r2->sgsymb;
    out_ptr = tmp_str;

    memset( tmp_str, '\0', 40 );
    
    while( *inp_ptr ) {
       if( isspace(*inp_ptr) )
           n_blanks++;
       if( isgraph(*inp_ptr) ) {
           *out_ptr++ = tolower( *inp_ptr );
            n_blanks = 0;
       }
       if( NRC_MAGIC_NUM == n_blanks ) 
           *out_ptr++ = ' ';

       inp_ptr++;
    }
    len = strlen( tmp_str );
    ret_val = malloc( len + 1 );
    if( !ret_val ) 
        return NULL;

    memcpy( ret_val, tmp_str, len );
    ret_val[len] = '\0';

    return ret_val;
}
