/* this function gets atom type information from an NRCVAX
 * .cd file.
 * Written by:
 *	Paul D. Boyle
 *	Department of Chemistry
 *	Box 8204
 *	North Carolina State University
 *	Raleigh, NC 27695-8204
 *
 *	March 1999
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version
 * 2 of the License, or (at your option) any later version.
 */
#include <stdlib.h>
#include <stdio.h>
#include <assert.h>

#include "sirinp.h"
#ifndef NRCVAX_H
#define NRCVAX_H
#include "nrcvax.h"
#endif

/* GetAtomTypeInfo() */

AtomTypeInfo *GetAtomTypeInfo( const Record_6 *r6, const Record_7 *r7 )
{
    AtomTypeInfo *ret_val;
    int i,
        n_types;
  
    assert( r6->ntyps > 0 ); 
    if( NRC_MAX_ATOM_TYPE < r6->ntyps ) {
        fputs( "**Warning** Number of atom types exceeds allowable limits.\n",
                stderr );
        return NULL;
    }
    if( SIR_MAX < r6->ntyps ) {
        fprintf( stderr, "**Warning** program will only use the first %d"
                 " atom types.\n", SIR_MAX );
        n_types = SIR_MAX;
    }
    else
       n_types = r6->ntyps;
   
    assert( n_types > 0 );
    fprintf( stdout, "Number of atoms types: %d\n", n_types ); 
    ret_val = malloc( n_types * sizeof(AtomTypeInfo) );
    if( !ret_val ) {
        fprintf( stderr, "error malloc() -- %s:%d. Exiting.\n", 
                         __FILE__, __LINE__ );
        return NULL;
    }
    
    for( i = 0; (i < n_types) && (i < 5); i++ )
                    ret_val[i] = r6->atom_info_1[i];

    if( (n_types > 5) && (NULL != r7) ) 
       for( i = 5; (i < n_types) && (i < SIR_MAX); i++ )
            ret_val[i] = r7->atom_info_2[i-5];

    return ret_val;
}
