/* this function takes an pointer to AtomTypeInfo (see nrcvax.h)
 * and returns a neatly formatted formula string suitable for
 * input into SIR.
 * Written by:
 *	Paul D. Boyle
 *	Department of Chemistry
 *	Box 8204
 *	North Carolina State University
 *	Raleigh, NC 27695-8204
 *
 *	March 1999
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version
 * 2 of the License, or (at your option) any later version.
 */
#include <stdlib.h>
#include <string.h>
#include <assert.h>

#include "sirinp.h"
#ifndef NRCVAX_H
#include "nrcvax.h"
#define NRCVAX_H
#endif
    
char *GetCellContents( const AtomTypeInfo *atoms, const int n_types )
{
   char (*formula)[FIELD_LEN];
   char *ret_val;
   int i;
   size_t len;

   assert( n_types > 0 );
   formula = malloc( len = n_types * sizeof *formula );
   if( !formula )
       return NULL;

   ret_val = malloc( len = n_types * FIELD_LEN + 1 );
   if( !ret_val )
       return NULL;

/* use a bunch of local variables in the following block of
 * code so that we avoid writing the AtomTypeInfo data directly
 * to the ret_val buffer.  This clears up the gibberish I was
 * getting before.  Do a char by char copy of atoms[i].atsymb
 * to the atom_id buffer and properly NUL terminate the atom_id
 * buffer.
 */
   for( i = 0; i < n_types; i++ ) {
      int j = 0;
      const char *src;
      char *dst;
      char atom_id[4];
      int atom_count = (int) atoms[i].atcnt + 0.5;
      memset( atom_id, '\0', 4 );
      src = atoms[i].atsymb;
      dst = atom_id;
      for( j = 0; j < 3; j++ ) *dst++ = *src++; 
      dst[3] = '\0';
      memset( formula[i], '\0', FIELD_LEN );
      sprintf( formula[i], "%s %d ", atom_id, atom_count ); 
      strcat( ret_val, formula[i] );
   }
  
   free( formula );

   ret_val[len] = '\0';
   return ret_val;
}
