/* this function gets the Job field from Record_1 of the .cd file
 * (see nrcvax.h).
 *
 * Written by:
 *	Paul D. Boyle
 *	Department of Chemistry
 *	Box 8204
 *	North Carolina State University
 *	Raleigh, NC 27695-8204
 *
 *	March 1999
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version
 * 2 of the License, or (at your option) any later version.
 */
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <ctype.h>

#include "sirinp.h"
#ifndef NRCVAX_H
#include "nrcvax.h"
#endif

#define JOB_LEN  48  /* see nrcvax.h for definition of Record_1 and 
                      * the lengths of the various fields.
                      */

char *GetJobname( const Record_1 *r1 )
{
    char *ret_val,
         *ptr1;
    const char *ptr2;
    char tmp_array[JOB_LEN];
    int  i = 0;
    
    memset(tmp_array, '\0', JOB_LEN);

/* don't use memcpy() for taking the Job name out of the record struct. I have
 * found difficulties reading data from the .cd files using the standard
 * C library functions.  Instead, use pointers to do a character by 
 * character copy.
 */
    ptr1 = tmp_array;
    ptr2 = r1->Job;
    for( i = 0; i < JOB_LEN; i++ ) *ptr1++ = *ptr2++;
    tmp_array[JOB_LEN - 1] = '\0';

/* clean up the possibly polluted FORTRAN character data, 
 * then copy to the returned pointer.
 */
    ptr1 = tmp_array;
    while( *ptr1 ) {
       if( isprint(*ptr1) ) 
         ptr1++;
       else  
         *ptr1++ = 0x20;
    }

    ret_val = malloc( JOB_LEN + 1 );
    if( !ret_val )
        return NULL;

    memcpy( ret_val, tmp_array, JOB_LEN );
    ret_val[JOB_LEN] = '\0';

    return ret_val;
}
