/* this is the main() function for sirinp.  It doesn't really do much
 * except call the other functions.
 * Written by:
 *	Paul D. Boyle
 *	Department of Chemistry
 *	Box 8204
 *	North Carolina State University
 *	Raleigh, NC 27695-8204
 *
 *	March 1999
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version
 * 2 of the License, or (at your option) any later version.
 */
#include <stdlib.h>
#include <stdio.h>
#include <getopt.h>

#include "sirinp.h"

int main( int argc, char **argv )
{
   int i_opt, 
       ret_val;
   struct data_files *files;

   if( argc < 2 ) {
       Usage();
       exit( EXIT_SUCCESS );
   }

   files = MakeFilenames( argv[argc-1] );
   if( !files ) {
     fprintf( stderr,
              "**Error ** %s:%d MakeFilenames() -- returned NULL. Exiting\n",
              __FILE__, __LINE__ );
     exit( EXIT_FAILURE );
   }

   if( 2  != argc ) { /* parse the command line, and do the work. */
       while( (i_opt = getopt(argc, argv, "chr")) != EOF ) {
           switch( i_opt ) {
             case 'c':  /* create .sir file only */
                ret_val = ProcessCDFile( files );
                if( 0 != ret_val )
                    fputs( "SIR input file creation failed.\n", stderr );
                else
                    fprintf( stdout, "SIR input file created from %s\n", files->cd );
                break;
             case 'r':  /* create .hkl file only */
                ret_val = ProcessREFile( files );
                if( -1 != ret_val )
                  fprintf( stdout, "%d reflections processed from %s\n", ret_val, files->re );
                else
                  fputs( "Creation of HKLF 4 file failed.\n", stderr );
                break;
             case 'h':
                Usage();
                exit( EXIT_SUCCESS );
             default: 
                Usage();
                break;
           }
       } 
   }
   else {            /* default is make both files. */
       ret_val = ProcessCDFile( files );
       if( 0 != ret_val )
           fputs( "SIR input file creation failed.\n", stderr );
       else
           fprintf( stdout, "SIR input file created from %s\n", files->cd );
 
       ret_val = ProcessREFile( files );
       if( -1 != ret_val )
           fprintf( stdout, "%d reflections processed from %s\n", ret_val, files->re );
       else
           fputs("HKLF 4 file creation failed.\n", stderr );
   }

   FreeDataStruct( files );

   exit( EXIT_SUCCESS );
}
