/* this function does the real work of reading the NRCVAX .re file
 * and outputting a SHELX HKLF 4 file.  The function returns the 
 * number of reflections processed if the function finished OK, and
 * returns a -1 on an error.
 * Written by:
 *	Paul D. Boyle
 *	Department of Chemistry
 *	Box 8204
 *	North Carolina State University
 *	Raleigh, NC 27695-8204
 *
 *	March 1999
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version
 * 2 of the License, or (at your option) any later version.
 */
#include <stdlib.h>
#include <stdio.h>

#include "sirinp.h"
#ifndef NRCVAX_H
#include "nrcvax.h"
#define NRCVAX_H
#endif

int ProcessREFile( const struct data_files *job )
{
    RE_Record  ref;
    Record_2   rec2;
    FILE       *re_file,
               *cd_file,
               *hkl_file;

    int record = 0; 
    float f2_sig;

/* open the files */
    re_file = fopen( job->re, "rb" );
    if( !re_file ) {
        perror( job->re );
        return -1;
    }
    
    cd_file = fopen( job->cd, "rb" );
    if( !cd_file ) {
        perror( job->cd );
        return -1;
    }
    
    hkl_file = fopen( job->hkl, "w" );
    if( !hkl_file ) {
        perror( job->hkl );
        return -1;
    }

/* get the centric/acentric flag from record 2 of the .cd file */
    ReadRecordFromNRCFile( CD_FILE, 2, &rec2, cd_file );
    fclose( cd_file );

/* now loop through the .re file and write the .hkl file */
    while( 1 ) {  /* keep looping until break condition is met. */
      ReadRecordFromNRCFile( RE_FILE, record, &ref, re_file );
      if( (0 == ref.h) &&
          (0 == ref.k) &&
          (0 == ref.l) ) break;

      record++;
      f2_sig = 1.0 / ref.sigma_Fo2;
      if( ref.Fo2 < OVER_FLOW_F2 )
          fprintf( hkl_file, HKLF4_FORMAT_1,
                   ref.h, ref.k, ref.l, ref.Fo2, f2_sig );
      else
          fprintf( hkl_file, HKLF4_FORMAT_2,
                   ref.h, ref.k, ref.l, ref.Fo2, f2_sig );

/* check for Friedel pairs */
      if( (0 == rec2.icen) && (0.0 != ref.sigma_Fo2_) ) {
         f2_sig = 1.0 / ref.sigma_Fo2_;
         if( ref.Fo2 < OVER_FLOW_F2 )
             fprintf( hkl_file, HKLF4_FORMAT_1,
                      -ref.h, -ref.k, -ref.l, ref.Fo2_, f2_sig );
         else
             fprintf( hkl_file, HKLF4_FORMAT_2,
                      -ref.h, -ref.k, -ref.l, ref.Fo2_, f2_sig );
      }
    }

    fprintf( hkl_file, HKLF4_FORMAT_1, 0, 0, 0, 0.0, 0.0 );
    fclose( re_file );
    fclose( hkl_file );
   
    return record;
}
