#ifndef _XOPEN_SOURCE
#define _XOPEN_SOURCE
#endif

#include <stdio.h>
#ifndef NRCVAX_H
#include "nrcvax.h"
#define NRCVAX_H
#endif

#define CD_FILE   ".cd"
#define RE_FILE   ".re"
#define SIR_FILE  ".sir"
#define HKLF_FILE ".hkl"
 
#define RECL_CD  400
#define NAME_LEN  40
#define SIR_MAX    8
#define NRC_MAX_ATOM_TYPE 12

#define HKLF4_FORMAT_1    "%4d%4d%4d%8.2f%8.2f\n"
#define HKLF4_FORMAT_2    "%4d%4d%4d%8.0f%8.2f\n"
#define SIR_HEADER_FORMAT "%%window\n%%structure %s\n%%init\n" \
                          "%%job sir92: %s\n%%data\n"
#define SIR_CELL_FORMAT   "     cell %6.3f %6.3f %6.3f %6.2f %6.2f %6.2f\n" 
#define SIR_SPACE_FORMAT  "     space %s\n"
#define SIR_CONT_FORMAT   "     cont  %s\n"
#define SIR_REFL_FORMAT   "     fosquare\n" \
                          "     reflections %s\n" \
                          "     format (3I4,2F8.2)\n"
#define SIR_DEFAULT_INST  "%%normal\n%%invariants\n%%continue\n"

#define OVER_FLOW_F2    99999.99
#define NRC_MAGIC_NUM  7
#define FIELD_LEN     10 

/* a structure to hold the NRCVAX .cd and .re file names,
 * as well as the sir input and hkl filenames.
 */
struct data_files {
       char *job;
       char *cd;
       char *re;
       char *sir;
       char *hkl;
       };

/* prototypes */
extern void Usage(void);
extern void FreeDataStruct(struct data_files *data);
extern struct data_files *MakeFilenames(const char *job_name);
extern int ProcessREFile(const struct data_files *job);
extern int ProcessCDFile(const struct data_files *job);
extern void ReadRecordFromNRCFile(char *type, int record, void *rec_ptr, FILE *nrc_file);
extern AtomTypeInfo *GetAtomTypeInfo(const Record_6 *r6, const Record_7 *r7);
extern char *ExtractSpaceGroupSymbol(const Record_2 *r2);
extern char *GetCellContents(const AtomTypeInfo *atoms, const int n_types);
extern char *GetJobname( const Record_1 *r1 );
